@@ -1,7 +1,7 @@
 ;;; tex-jp.el --- Support for Japanese TeX.
 
 ;; Copyright (C) 1999, 2001 Hidenobu Nabetani <nabe@debian.or.jp>
-;; Copyright (C) 2002, 2003, 2004 Free Software Foundation
+;; Copyright (C) 2002, 2003, 2004, 2005 Free Software Foundation
 
 ;; Author:     KOBAYASHI Shinji <koba@flab.fujitsu.co.jp>
 ;; Maintainer: Masayuki Ataka <ataka@milk.freemail.ne.jp>
@@ -130,13 +130,15 @@
   '(("j-article")
     ("j-report")
     ("j-book")
-    ("jarticle")
-    ("jbook")
-    ("jreport")
     ("jslides")
+    ("jarticle")
+    ("jreport")
+    ("jbook")
     ("tarticle")
     ("treport")
-    ("tbook"))
+    ("tbook")
+    ("jsarticle")
+    ("jsbook"))
   "*List of Japanese document styles."
   :group 'AUCTeX-jp
   :type '(repeat (group (string :format "%v"))))
@@ -258,298 +260,6 @@ Set japanese-TeX-mode to t, and enters latex-mode."
 	(setq japanese-TeX-mode nil))))
 
 
-;;; MULE paragraph filling.
-
-;; This function is copied from
-;; fill-region-as-paragraph in fill.el --- fill commands for Emacs
-;; Copyright (C) 1985, 86, 92, 94, 95, 96, 1997 Free Software Foundation, Inc.
-(defun LaTeX-fill-region-as-para-do (from to justify)
-  "Fill region as one paragraph: break lines to fit `fill-column'."
-  (setq x justify)
-  (unless (memq justify '(t nil none full center left right))
-    (setq justify 'full))
-  (setq y justify)
-  ;; Arrange for undoing the fill to restore point.
-  (if (and buffer-undo-list (not (eq buffer-undo-list t)))
-      (setq buffer-undo-list (cons (point) buffer-undo-list)))
-
-  ;; Make sure "to" is the endpoint.
-  (goto-char (min from to))
-  (setq to   (max from to))
-  ;; Ignore blank lines at beginning of region.
-  (skip-chars-forward " \t\n")
-
-  (let ((from-plus-indent (point))
-	(oneleft nil))
-
-    (beginning-of-line)
-    (setq from (point))
-
-    ;; Delete all but one soft newline at end of region.
-    ;; And leave TO before that one.
-    (goto-char to)
-    (while (and (> (point) from) (eq ?\n (char-after (1- (point)))))
-      (if (and oneleft
-	       (not (and use-hard-newlines
-			 (get-text-property (1- (point)) 'hard))))
-	  (delete-backward-char 1)
-	(backward-char 1)
-	(setq oneleft t)))
-    (setq to (point))
-;;;     ;; If there was no newline, and there is text in the paragraph, then
-;;;     ;; create a newline.
-;;;     (if (and (not oneleft) (> to from-plus-indent))
-;;;	(newline))
-    (goto-char from-plus-indent))
-
-  (if (not (> to (point)))
-      nil ; There is no paragraph, only whitespace: exit now.
-
-    (or justify (setq justify (current-justification)))
-
-    ;; Don't let Adaptive Fill mode alter the fill prefix permanently.
-    (let ((fill-prefix fill-prefix))
-      ;; Figure out how this paragraph is indented, if desired.
-      (if (and adaptive-fill-mode
-	       (or (null fill-prefix) (string= fill-prefix "")))
-	  (setq fill-prefix (fill-context-prefix from to)))
-
-      (save-restriction
-	(goto-char from)
-	(beginning-of-line)
-	(narrow-to-region (point) to)
-
-	(if (not justify)	    ; filling disabled: just check indentation
-	    (progn
-	      (goto-char from)
-	      (while (not (eobp))
-		(if (and (not (eolp))
-			 (< (current-indentation) (current-left-margin)))
-		    (LaTeX-indent-line))
-		(forward-line 1)))
-
-	  (if use-hard-newlines
-	      (remove-text-properties from (point-max) '(hard nil)))
-	  ;; Make sure first line is indented (at least) to left margin...
-	  (if (or (memq justify '(right center))
-		  (< (current-indentation) (current-left-margin)))
-	      (LaTeX-indent-line))
-	  ;; Delete the fill prefix from every line except the first.
-	  ;; The first line may not even have a fill prefix.
-	  (goto-char from)
-	  (let ((fpre (and fill-prefix (not (equal fill-prefix ""))
-			   (concat "[ \t]*"
-				   (regexp-quote fill-prefix)
-				   "[ \t]*"))))
-	    (and fpre
-		 (progn
-		   (if (>= (+ (current-left-margin) (length fill-prefix))
-			   (current-fill-column))
-		       (error "fill-prefix too long for specified width"))
-		   (goto-char from)
-		   (forward-line 1)
-		   (while (not (eobp))
-		     (if (looking-at fpre)
-			 (delete-region (point) (match-end 0)))
-		     (forward-line 1))
-		   (goto-char from)
-		   (if (looking-at fpre)
-		       (goto-char (match-end 0)))
-		   (setq from (point)))))
-	  ;; Remove indentation from lines other than the first.
-	  (beginning-of-line 2)
-	  (indent-region (point) (point-max) 0)
-	  (goto-char from)
-
-	  ;; FROM, and point, are now before the text to fill,
-	  ;; but after any fill prefix on the first line.
-
-	  ;; Make sure sentences ending at end of line get an extra space.
-	  ;; loses on split abbrevs ("Mr.\nSmith")
-	  (while (re-search-forward "[.?!][])}\"']*$" nil t)
-	    (or (eobp) (insert-and-inherit ?\ )))
-	  (goto-char from)
-	  ;; The character category `|' means that we can break a line
-	  ;; at the character.  Since we don't need a space between
-	  ;; them, delete all newlines between them ...
-	  (while (re-search-forward "\\c|\n\\|\n\\c|" nil t)
-	    (if (bolp)
-		(delete-char -1)
-	      (if (= (char-before (match-beginning 0)) ?\ )
-		  ;; ... except when there is end of sentence.  The
-		  ;; variable `sentence-end-double-space' is handled
-		  ;; properly later.
-		  nil
-		(delete-region (match-beginning 0) (1+ (match-beginning 0))))))
-	  (goto-char from)
-	  (skip-chars-forward " \t")
-	  ;; Then change all newlines to spaces.
-	  (subst-char-in-region from (point-max) ?\n ?\ )
-	  (if (not (eq justify 'full))
-	      nil
-	    (canonically-space-region (point) (point-max))
-	    (goto-char (point-max))
-	    (delete-horizontal-space)
-	    (insert-and-inherit " "))
-	  (goto-char (point-min))
-
-	  ;; This is the actual filling loop.
-	  (let ((prefixcol 0) linebeg)
-	    (while (not (eobp))
-	      (setq linebeg (point))
-	      (move-to-column (1+ (current-fill-column)))
-	      (if (eobp)
-		  (delete-horizontal-space)
-		;; Move back to the point where we can break the line
-		;; at.  We break the line between word or after/before
-		;; the character which has character category `|'.  We
-		;; search space, \c| followed by a character, or \c|
-		;; following a character.  If not found, place
-		;; the point at linebeg.
-		(if (re-search-backward " \\|\\c|.\\|.\\c|" linebeg 0)
-		    ;; In case of space, we place the point at next to
-		    ;; the point where the break occurs acutually,
-		    ;; because we don't want to change the following
-		    ;; logic of original Emacs.  In case of \c|, the
-		    ;; point is at the place where the break occurs.
-		    (forward-char 1))
-		;; Don't break after a period followed by just one space.
-		;; Move back to the previous place to break.
-		;; The reason is that if a period ends up at the end of a line,
-		;; further fills will assume it ends a sentence.
-		;; If we now know it does not end a sentence,
-		;; avoid putting it at the end of the line.
-		(while (or (and sentence-end-double-space
-				(> (point) (+ linebeg 2))
-				(eq (preceding-char) ?\ )
-				(not (eq (following-char) ?\ ))
-				(eq (char-after (- (point) 2)) ?\.)
-				(progn (forward-char -2) t))
-			   (and fill-nobreak-predicate
-				(funcall fill-nobreak-predicate)
-				(goto-char (match-beginning 0))))
-		  (if (re-search-backward " \\|\\c|.\\|.\\c|" linebeg 0)
-		      (forward-char 1)))
-		;; If the left margin and fill prefix by themselves
-		;; pass the fill-column. or if they are zero
-		;; but we have no room for even one word,
-		;; keep at least one word or a character which has
-		;; category `|'anyway .
-		;; This handles ALL BUT the first line of the paragraph.
-		(if (if (zerop prefixcol)
-			(save-excursion
-			  (skip-chars-backward " \t" linebeg)
-			  (bolp))
-		      (>= prefixcol (current-column)))
-		    ;; Ok, skip at least one word or one \c| character.
-		    ;; Meanwhile, don't stop at a period followed by one space.
-		    (let ((first t))
-		      (move-to-column prefixcol)
-		      (while (and (not (eobp))
-				  (or first
-				      (and (not (bobp))
-					   sentence-end-double-space
-					   (save-excursion (forward-char -1)
-							   (and (looking-at "\\. ")
-								(not (looking-at "\\.  ")))))
-				      (and fill-nobreak-predicate
-					   (funcall fill-nobreak-predicate))))
-			;; Find a breakable point while ignoring the
-			;; following spaces.
-			(skip-chars-forward " \t")
-			(if (looking-at "\\c|")
-			    (forward-char 1)
-			  (let ((pos (save-excursion
-				       (skip-chars-forward "^ \n\t")
-				       (point))))
-			    (if (re-search-forward "\\c|" pos t)
-				(forward-char -1)
-			      (goto-char pos))))
-			(setq first nil)))
-		  ;; Normally, move back over the single space between the words.
-		  (if (= (preceding-char) ?\ ) (forward-char -1))
-		  ;; Do KINSOKU processing.
-		  (if (and enable-multibyte-characters enable-kinsoku
-			   (save-excursion
-			     (goto-char (point-min))
-			     (skip-chars-forward "\0-\177")
-			     (/= (point) (point-max))))
-		      (kinsoku linebeg)))
-
-		;; If the left margin and fill prefix by themselves
-		;; pass the fill-column, keep at least one word.
-		;; This handles the first line of the paragraph.
-		(if (and (zerop prefixcol)
-			 (let ((fill-point (point)) nchars)
-			   (save-excursion
-			     (move-to-left-margin)
-			     (setq nchars (- fill-point (point)))
-			     (or (< nchars 0)
-				 (and fill-prefix
-				      (< nchars (length fill-prefix))
-				      (string= (buffer-substring (point) fill-point)
-					       (substring fill-prefix 0 nchars)))))))
-		    ;; Ok, skip at least one word.  But
-		    ;; don't stop at a period followed by just one space.
-		    (let ((first t))
-		      (while (and (not (eobp))
-				  (or first
-				      (and (not (bobp))
-					   sentence-end-double-space
-					   (save-excursion (forward-char -1)
-							   (and (looking-at "\\. ")
-								(not (looking-at "\\.  ")))))
-				      (and fill-nobreak-predicate
-					   (funcall fill-nobreak-predicate))))
-			;; Find a breakable point while ignoring the
-			;; following spaces.
-			(skip-chars-forward " \t")
-			(if (looking-at "\\c|")
-			    (forward-char 1)
-			  (let ((pos (save-excursion
-				       (skip-chars-forward "^ \n\t")
-				       (point))))
-			    (if (re-search-forward "\\c|" pos t)
-				(forward-char -1)
-			      (goto-char pos))))
-			(setq first nil))))
-		;; Check again to see if we got to the end of the paragraph.
-		(if (save-excursion (skip-chars-forward " \t") (eobp))
-		    (delete-horizontal-space)
-		  ;; Replace whitespace here with one newline, then indent to left
-		  ;; margin.
-		  (skip-chars-backward " \t")
-		  (if (and (= (following-char) ?\ )
-			   (or (aref (char-category-set (preceding-char)) ?|)
-			       (looking-at "[ \t]+\\c|")))
-		      ;; We need one space at end of line so that
-		      ;; further filling won't delete it.  NOTE: We
-		      ;; intentionally leave this one space to
-		      ;; distingush the case that user wants to put
-		      ;; space between \c| characters.
-		      (forward-char 1))
-		  (insert ?\n)
-		  ;; Give newline the properties of the space(s) it replaces
-		  (set-text-properties (1- (point)) (point)
-				       (text-properties-at (point)))
-		  (LaTeX-indent-line)
-		  ;; Set prefixcol so whitespace in the prefix won't get lost.
-		  (and fill-prefix (not (equal fill-prefix ""))
-		       (setq prefixcol (current-column)))))
-	      ;; Justify the line just ended, if desired.
-	      (if justify
-		(if (save-excursion (skip-chars-forward " \t") (eobp))
-		    (progn
-		      (delete-horizontal-space)
-		      (justify-current-line justify t t))
-		    (forward-line -1)
-		    (justify-current-line justify nil t)
-		    (forward-line 1))))))
-	;; Leave point after final newline.
-	(goto-char (point-max)))
-      (unless (eobp)
-	(forward-char 1)))))
-
 ;;; Support for various self-insert-command
 
 (cond ((fboundp 'can-n-egg-self-insert-command)
